#!/bin/bash
#
# packager                          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
#
# dernires rvisions       : 16/1/2011
#
#package			: cryptopp
#homepage			: http://sourceforge.net/projects/cryptopp/
#source location	: http://mesh.dl.sourceforge.net/sourceforge/cryptopp/cryptopp552.zip
#dependency         : 

softname='cryptopp'
softversion='561'
packageversion='70.1'

arch='i486'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname$softversion.zip"
src="$buildir/$softname$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://mesh.dl.sourceforge.net/sourceforge/cryptopp/$softname$softversion.zip

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/lib
mkdir -p $dest/$prefix/include/cryptopp
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
        |-----handy-ruler------------------------------------------------------|
cryptopp: cryptopp - a free C++ library for cryptography
cryptopp:
cryptopp: free C++ library for cryptography: includes ciphers, message
cryptopp: authentication codes, one-way hash functions, public-key 
cryptopp: cryptosystems, and key agreement schemes
cryptopp:
cryptopp: 
cryptopp:
cryptopp: 
cryptopp:
cryptopp: 
EOF

# check if source is present
if [ -f $softname$softversion.zip ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
unzip -d $softname$softversion $srcpkg 
cd $src

# building
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
    mv GNUmakefile makefile
    make 
	cp *.h $dest/$prefix/include/cryptopp
	cp *.a $dest/$prefix/lib

# add 'default' files
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      Readme.txt\
      $dest/usr/doc/$softname-$softversion

# Strip Executables 
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "cxxlibs,gcc" > $package.dep

# erase source
rm -rf $src
rm -rf $dest

# generate source file
echo http://users.zenwalk.org/user-accounts/bip/EXTRA/l/crypto++/source/build-cryptopp.sh > $package.src
echo $source >>$package.src

# log
) 2>&1 | tee "$softname-$softversion-build.log"
